summaryrefslogtreecommitdiff
path: root/src/modlistview.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/modlistview.h')
-rw-r--r--src/modlistview.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/modlistview.h b/src/modlistview.h
index 53c71458..13f868c6 100644
--- a/src/modlistview.h
+++ b/src/modlistview.h
@@ -61,9 +61,10 @@ public:
//
bool hasCollapsibleSeparators() const;
// the column by which the mod list is currently sorted
//
int sortColumn() const;
+ Qt::SortOrder sortOrder() const;
// the current group mode
//
@@ -61,9 +61,10 @@ public:
//
bool hasCollapsibleSeparators() const;
- // the column by which the mod list is currently sorted
+ // the column/order by which the mod list is currently sorted
//
int sortColumn() const;